@@ -217,7 +217,7 @@ def y_to_lat_spherical(y):
     return np.degrees(np.arctan(np.sinh(y / 6378137.0)))
 
 
-def ms_to_kmh(move_data, label_speed=constants.SPEED_TO_PREV, new_label=None):
+def ms_to_kmh(move_data, label_speed=constants.SPEED_TO_PREV, new_label=None, inplace=True):
     """
     Convert values, in ms, in label_speed column to kmh.
 
@@ -232,10 +232,18 @@ def ms_to_kmh(move_data, label_speed=constants.SPEED_TO_PREV, new_label=None):
     new_label: String, optional, default None.
         Represents a new column that will contain the conversion result.
 
+    inplace: Boolean, optional, default True.
+        Wether the operation will be done in the original dataframe
+
     Returns
     -------
+        move_data: dataframe or None
+            A new dataframe with the converted feature if operation
+            not done inplace
     """
     try:
+        if not inplace:
+            move_data = move_data[:]
         if label_speed not in move_data:
             move_data.generate_dist_time_speed_features()
         move_data[label_speed] = move_data[label_speed].transform(
@@ -243,11 +251,13 @@ def ms_to_kmh(move_data, label_speed=constants.SPEED_TO_PREV, new_label=None):
         )
         if new_label is not None:
             move_data.rename(columns={label_speed: new_label}, inplace=True)
+        if not inplace:
+            return move_data
     except Exception as e:
         raise e
 
 
-def kmh_to_ms(move_data, label_speed=constants.SPEED_TO_PREV, new_label=None):
+def kmh_to_ms(move_data, label_speed=constants.SPEED_TO_PREV, new_label=None, inplace=True):
     """
     Convert values, in kmh, in label_speed column to ms.
 
@@ -262,23 +272,34 @@ def kmh_to_ms(move_data, label_speed=constants.SPEED_TO_PREV, new_label=None):
     new_label: String, optional, default None.
         Represents a new column that will contain the conversion result.
 
+    inplace: Boolean, optional, default True.
+        Wether the operation will be done in the original dataframe
+
     Returns
     -------
+        move_data: dataframe or None
+            A new dataframe with the converted feature if operation
+            not done inplace
     """
     try:
+        if not inplace:
+            move_data = move_data[:]
         if label_speed not in move_data:
             move_data.generate_dist_time_speed_features()
+            ms_to_kmh(move_data, label_speed, new_label)
         move_data[label_speed] = move_data[label_speed].transform(
             lambda row: row / 3.6
         )
         if new_label is not None:
             move_data.rename(columns={label_speed: new_label}, inplace=True)
+        if not inplace:
+            return move_data
     except Exception as e:
         raise e
 
 
 def meters_to_kilometers(
-    move_data, label_distance=constants.DIST_TO_PREV, new_label=None
+    move_data, label_distance=constants.DIST_TO_PREV, new_label=None, inplace=True
 ):
     """
     Convert values, in meters, in label_distance column to kilometers.
@@ -294,10 +315,18 @@ def meters_to_kilometers(
     new_label: String, optional, default None.
         Represents a new column that will contain the conversion result.
 
+    inplace: Boolean, optional, default True.
+        Wether the operation will be done in the original dataframe
+
     Returns
     -------
+        move_data: dataframe or None
+            A new dataframe with the converted feature if operation
+            not done inplace
     """
     try:
+        if not inplace:
+            move_data = move_data[:]
         if label_distance not in move_data:
             move_data.generate_dist_time_speed_features()
         move_data[label_distance] = move_data[label_distance].transform(
@@ -305,12 +334,14 @@ def meters_to_kilometers(
         )
         if new_label is not None:
             move_data.rename(columns={label_distance: new_label}, inplace=True)
+        if not inplace:
+            return move_data
     except Exception as e:
         raise e
 
 
 def kilometers_to_meters(
-    move_data, label_distance=constants.DIST_TO_PREV, new_label=None
+    move_data, label_distance=constants.DIST_TO_PREV, new_label=None, inplace=True
 ):
     """
     Convert values, in kilometers, in label_distance column to meters.
@@ -326,23 +357,34 @@ def kilometers_to_meters(
     new_label: String, optional, default None.
         Represents a new column that will contain the conversion result.
 
+    inplace: Boolean, optional, default True.
+        Wether the operation will be done in the original dataframe
+
     Returns
     -------
+        move_data: dataframe or None
+            A new dataframe with the converted feature if operation
+            not done inplace
     """
     try:
+        if not inplace:
+            move_data = move_data[:]
         if label_distance not in move_data:
             move_data.generate_dist_time_speed_features()
+            meters_to_kilometers(move_data, label_distance, new_label)
         move_data[label_distance] = move_data[label_distance].transform(
             lambda row: row * 1000
         )
         if new_label is not None:
             move_data.rename(columns={label_distance: new_label}, inplace=True)
+        if not inplace:
+            return move_data
     except Exception as e:
         raise e
 
 
 def seconds_to_minutes(
-    move_data, label_time=constants.TIME_TO_PREV, new_label=None
+    move_data, label_time=constants.TIME_TO_PREV, new_label=None, inplace=True
 ):
     """
     Convert values, in seconds, in label_distance column to minutes.
@@ -358,10 +400,18 @@ def seconds_to_minutes(
     new_label: String, optional, default None.
         Represents a new column that will contain the conversion result.
 
+    inplace: Boolean, optional, default True.
+        Wether the operation will be done in the original dataframe
+
     Returns
     -------
+        move_data: dataframe or None
+            A new dataframe with the converted feature if operation
+            not done inplace
     """
     try:
+        if not inplace:
+            move_data = move_data[:]
         if label_time not in move_data:
             move_data.generate_dist_time_speed_features()
         move_data[label_time] = move_data[label_time].transform(
@@ -369,12 +419,14 @@ def seconds_to_minutes(
         )
         if new_label is not None:
             move_data.rename(columns={label_time: new_label}, inplace=True)
+        if not inplace:
+            return move_data
     except Exception as e:
         raise e
 
 
 def minute_to_seconds(
-    move_data, label_time=constants.TIME_TO_PREV, new_label=None
+    move_data, label_time=constants.TIME_TO_PREV, new_label=None, inplace=True
 ):
     """
     Convert values, in minutes, in label_distance column to seconds.
@@ -390,23 +442,34 @@ def minute_to_seconds(
     new_label: String, optional, default None.
         Represents a new column that will contain the conversion result.
 
+    inplace: Boolean, optional, default True.
+        Wether the operation will be done in the original dataframe
+
     Returns
     -------
+        move_data: dataframe or None
+            A new dataframe with the converted feature if operation
+            not done inplace
     """
     try:
+        if not inplace:
+            move_data = move_data[:]
         if label_time not in move_data:
             move_data.generate_dist_time_speed_features()
+            seconds_to_minutes(move_data, label_time, new_label)
         move_data[label_time] = move_data[label_time].apply(
             lambda row: row * 60.0
         )
         if new_label is not None:
             move_data.rename(columns={label_time: new_label}, inplace=True)
+        if not inplace:
+            return move_data
     except Exception as e:
         raise e
 
 
 def minute_to_hours(
-    move_data, label_time=constants.TIME_TO_PREV, new_label=None
+    move_data, label_time=constants.TIME_TO_PREV, new_label=None, inplace=True
 ):
     """
     Convert values, in minutes, in label_distance column to hours.
@@ -422,23 +485,34 @@ def minute_to_hours(
     new_label : String, optional, default None.
         Represents a new column that will contain the conversion result.
 
+    inplace: Boolean, optional, default True.
+        Wether the operation will be done in the original dataframe
+
     Returns
     -------
+        move_data: dataframe or None
+            A new dataframe with the converted feature if operation
+            not done inplace
     """
     try:
+        if not inplace:
+            move_data = move_data[:]
         if label_time not in move_data:
             move_data.generate_dist_time_speed_features()
+            seconds_to_minutes(move_data, label_time, new_label)
         move_data[label_time] = move_data[label_time].apply(
             lambda row: row / 60.0
         )
         if new_label is not None:
             move_data.rename(columns={label_time: new_label}, inplace=True)
+        if not inplace:
+            return move_data
     except Exception as e:
         raise e
 
 
 def hours_to_minute(
-    move_data, label_time=constants.TIME_TO_PREV, new_label=None
+    move_data, label_time=constants.TIME_TO_PREV, new_label=None, inplace=True
 ):
     """
     Convert values, in hours, in label_distance column to minute.
@@ -454,23 +528,34 @@ def hours_to_minute(
     new_label : String, optional, default None.
         Represents a new column that will contain the conversion result.
 
+    inplace: Boolean, optional, default True.
+        Wether the operation will be done in the original dataframe
+
     Returns
     -------
+        move_data: dataframe or None
+            A new dataframe with the converted feature if operation
+            not done inplace
     """
     try:
+        if not inplace:
+            move_data = move_data[:]
         if label_time not in move_data:
             move_data.generate_dist_time_speed_features()
+            seconds_to_hours(move_data, label_time, new_label)
         move_data[label_time] = move_data[label_time].apply(
             lambda row: row * 60.0
         )
         if new_label is not None:
             move_data.rename(columns={label_time: new_label}, inplace=True)
+        if not inplace:
+            return move_data
     except Exception as e:
         raise e
 
 
 def seconds_to_hours(
-    move_data, label_time=constants.TIME_TO_PREV, new_label=None
+    move_data, label_time=constants.TIME_TO_PREV, new_label=None, inplace=True
 ):
     """
     Convert values, in seconds, in label_distance column to hours.
@@ -486,10 +571,18 @@ def seconds_to_hours(
     new_label : String, optional, default None.
         Represents a new column that will contain the conversion result.
 
+    inplace: Boolean, optional, default True.
+        Wether the operation will be done in the original dataframe
+
     Returns
     -------
+        move_data: dataframe or None
+            A new dataframe with the converted feature if operation
+            not done inplace
     """
     try:
+        if not inplace:
+            move_data = move_data[:]
         if label_time not in move_data:
             move_data.generate_dist_time_speed_features()
         move_data[label_time] = move_data[label_time].apply(
@@ -497,12 +590,14 @@ def seconds_to_hours(
         )
         if new_label is not None:
             move_data.rename(columns={label_time: new_label}, inplace=True)
+        if not inplace:
+            return move_data
     except Exception as e:
         raise e
 
 
 def hours_to_seconds(
-    move_data, label_time=constants.TIME_TO_PREV, new_label=None
+    move_data, label_time=constants.TIME_TO_PREV, new_label=None, inplace=True
 ):
     """
     Convert values, in hours, in label_distance column to seconds.
@@ -518,16 +613,27 @@ def hours_to_seconds(
     new_label : String, optional, default None.
         Represents a new column that will contain the conversion result.
 
+    inplace: Boolean, optional, default True.
+        Wether the operation will be done in the original dataframe
+
     Returns
     -------
+        move_data: dataframe or None
+            A new dataframe with the converted feature if operation
+            not done inplace
     """
     try:
+        if not inplace:
+            move_data = move_data[:]
         if label_time not in move_data:
             move_data.generate_dist_time_speed_features()
+            seconds_to_hours(move_data, label_time, new_label)
         move_data[label_time] = move_data[label_time].apply(
             lambda row: row * 3600.0
         )
         if new_label is not None:
             move_data.rename(columns={label_time: new_label}, inplace=True)
+        if not inplace:
+            return move_data
     except Exception as e:
         raise e
